#
from enigma import *
from Screens.Screen import Screen
from Screens.MessageBox import MessageBox
from Screens.InputBox import InputBox
from Screens.ChoiceBox import ChoiceBox
from Components.ActionMap import ActionMap, NumberActionMap
from Components.ScrollLabel import ScrollLabel
from Components.GUIComponent import *
from Components.MenuList import MenuList
from Components.Input import Input
from Screens.Console import Console
from Plugins.Plugin import PluginDescriptor
from Screens.ImageWizard import ImageWizard
from Plugins.Plugin import PluginDescriptor

import os

###############################################################################
timeshiftsave_pluginversion = "1.0"
timeshiftsave_path = "/media/hdd/movie"
timeshiftsave_file = "/media/hdd/*timeshift*"
timeshiftsave_script = "cptimeshift.sh"
timeshiftsave_pluginpath = "/usr/lib/enigma2/python/Plugins/Extensions/Timeshiftsave"

###############################################################################
def main(session,**kwargs):
    try:    
     	session.open(Timeshiftsave)
    except:
        print "[TIMESHIFTSAVE] Pluginexecution failed"
###############################################################################
def autostart(reason,**kwargs):
    if reason == 0:
        print "[TIMESHIFTSAVE] no autostart"
###############################################################################
def Plugins(**kwargs):
    return PluginDescriptor(
        name="Timeshiftsave", 
        description="plugin to do save Timeshift recordings", 
        where = PluginDescriptor.WHERE_PLUGINMENU,
        fnc = main
        )
###############################################################################
###############################################################################
class Timeshiftsave(Screen):
    skin = """
        <screen position="100,100" size="500,400" title="Timeshiftsave Menu" >
            <widget name="menu" position="10,10" size="490,390" scrollbarMode="showOnDemand" />
        </screen>"""
        
    def __init__(self, session, args = 0):
        self.skin = Timeshiftsave.skin
        self.session = session
        Screen.__init__(self, session)
        self.menu = args
        list = []
        list.append((_("save current timeshift recording (only 1 allowed)"), "backupwizzard"))
        list.append((_("delete saved timeshift"), "deletewizzard"))
        list.append((_("rename saved timeshift"), "renamewizzard"))
        list.append((_("list   unsaved and lost timeshifts"), "list"))
        list.append((_("clean  lost and unsaved timeshifts"), "clean"))
        list.append((_("about"), "about"))        
        self["menu"] = MenuList(list)
        self["actions"] = ActionMap(["WizardActions", "DirectionActions"],{"ok": self.go,"back": self.close,}, -1)
        
    def go(self):
        returnValue = self["menu"].l.getCurrentSelection()[1]
        if returnValue is not None:
           if returnValue is "backupwizzard":
               BackupWizzard(self.session)
           elif returnValue is "renamewizzard":
               RenameWizzard(self.session)
           elif returnValue is "deletewizzard":
               DeleteWizzard(self.session)
           elif returnValue is "list":
               title = "Listing lost and unsaved timeshifts at /media/hdd"
               cmd = "%s/%s list" % (timeshiftsave_pluginpath,timeshiftsave_script)
               self.session.open(Console,_(title),[cmd])
           elif returnValue is "clean":
               title = "Cleaning all unsaved and lost timeshifts at /media/hdd"
               cmd = "%s/%s clean" % (timeshiftsave_pluginpath,timeshiftsave_script)
               self.session.open(Console,_(title),[cmd])
           elif returnValue is "about":
             self.session.open(MessageBox,_("Timeshiftsave Enigma2 Plugin %s\n\nTimeshiftsave tool\n\nEnjoy saving your Timeshift recordings with your remote control !" % timeshiftsave_pluginversion), MessageBox.TYPE_INFO)

###############################################################################
###############################################################################

class BackupWizzard(Screen):
    def __init__(self, session):

        self.session = session
        self.askForBackupName()

    def askForBackupName(self):
	       self.session.openWithCallback(self.processingBackup,InputBox, title=_("Enter name for saving current Timeshift"), text="timeshift", maxSize=False, type=Input.TEXT)

    def processingBackup(self,targetname):
        if targetname is None:
            self.skipBackup("Timeshift save name is NONE, skipping save")
        else:
            self.targetname = targetname
            self.session.openWithCallback(self.TimeshiftBackup,MessageBox,_("are you sure to save current Timeshift to %s ?" % (self.targetname)), MessageBox.TYPE_YESNO)

    def TimeshiftBackup(self,answer):
        if answer is None:
            self.skipBackup("answer is None")
        if answer is False:
            self.skipBackup("you were not confirming")
        else:
            title = "Backup of Timeshift to %s/%s.ts" %(timeshiftsave_path,self.targetname)
            cmd = "%s/%s save %s" % (timeshiftsave_pluginpath,timeshiftsave_script,self.targetname)
            self.session.open(Console,_(title),[cmd])
            
    def skipBackup(self,reason):
        self.session.open(MessageBox,_("Saving Timeshift was canceled, because %s" % reason), MessageBox.TYPE_WARNING)
        
        
###############################################################################
###############################################################################

class RenameWizzard(Screen):
    def __init__(self, session):

        self.session = session
        self.askForRenameName()

    def askForRenameName(self):
	       self.session.openWithCallback(self.processingRename,InputBox, title=_("Enter a new name for saved Timeshift"), text="timeshift", maxSize=False, type=Input.TEXT)

    def processingRename(self,targetname):
        if targetname is None:
            self.skipRename("New name for saved Timeshift is NONE, skipping rename")
        else:
            self.targetname = targetname
            self.session.openWithCallback(self.TimeshiftRename,MessageBox,_("are you sure to rename saved Timeshift recording to %s ?" % (self.targetname)), MessageBox.TYPE_YESNO)

    def TimeshiftRename(self,answer):
        if answer is None:
            self.skipRename("answer is None")
        if answer is False:
            self.skipRename("you were not confirming")
        else:
            title = "Renaming saved Timeshift to %s/%s.ts" %(timeshiftsave_path,self.targetname)
            cmd = " %s/%s rename %s" % (timeshiftsave_pluginpath,timeshiftsave_script,self.targetname)
            self.session.open(Console,_(title),[cmd])
            
    def skipRename(self,reason):
        self.session.open(MessageBox,_("Renaming saved Timeshift was canceled, because %s" % reason), MessageBox.TYPE_WARNING)
        
        
###############################################################################
###############################################################################

class DeleteWizzard(Screen):
    def __init__(self, session):

        self.session = session
        self.askForDeleteName()

    def askForDeleteName(self):
	       self.session.openWithCallback(self.processingDelete,InputBox, title=_("Enter name for saved Timeshift delete"), text="timeshift", maxSize=False, type=Input.TEXT)

    def processingDelete(self,targetname):
        if targetname is None:
            self.skipBackup("Name for saved Timeshift delete is NONE, skipping delete")
        else:
            self.targetname = targetname
            self.session.openWithCallback(self.TimeshiftDelete,MessageBox,_("are you sure to delete saved Timeshift recording %s ?" % (self.targetname)), MessageBox.TYPE_YESNO)

    def TimeshiftDelete(self,answer):
        if answer is None:
            self.skipDelete("answer is None")
        if answer is False:
            self.skipDelete("you were not confirming")
        else:
            title = "Deleting saved Timeshift %s/%s" %(timeshiftsave_path, self.targetname)
            cmd = "%s/%s delete %s" % (timeshiftsave_pluginpath,timeshiftsave_script,self.targetname)
            self.session.open(Console,_(title),[cmd])
            
    def skipDelete(self,reason):
        self.session.open(MessageBox,_("Timeshift delete was canceled, because %s" % reason), MessageBox.TYPE_WARNING)
        
        
###############################################################################
